import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { jwtDecode } from 'jwt-decode';
import { observer } from 'mobx-react-lite';
import { Typography } from '@mui/material';
import AdminButton from '../../components/button/AdminButton';
import AdminInput from '../../components/input/AdminInput';
import { APP_CONFIG } from '../../config/app-config';
import { FirebaseUserRoles } from '../../constants/common-constants';
import { LOCAL_STORAGE_KEYS } from '../../constants/common-constants';
import { InputPresets } from '../../constants/input-field-constants';
import { ROUTES } from '../../constants/route-constants';
import { ToastPreset } from '../../constants/toast-constants';
import { translate } from '../../locales/translations';
import { useStore } from '../../models/root-store/root-store';
import { forgotPassword, logOut, loginWithEmailPassword } from '../../utils/firebase-utils';
import './loginPage-style.scss';
const LoginPage = observer(() => {
    const navigate = useNavigate();
    const store = useStore();
    const { viewStore, domainStore } = store;
    const { userStore } = domainStore;
    const { checkEmailExists, isEmailExisting } = userStore;
    const { toastStore } = viewStore;
    const { popToast } = toastStore;
    const { loginMessage, LoginIcon, loginTitle, loginMessageTitle } = APP_CONFIG;
    const [email, setEmail] = useState('');
    const [password, setPassword] = useState('');
    const [errors, setErrors] = useState({
        email: '',
        password: '',
    });
    const handleEmailChange = (value) => {
        setEmail(String(value));
    };
    const handlePasswordChange = (value) => {
        setPassword(String(value));
    };
    const handleLogin = async () => {
        try {
            if (!email || !password) {
                setErrors({
                    email: email ? '' : translate.pages.login.emailError,
                    password: password ? '' : translate.pages.login.passwordError,
                });
                return;
            }
            const result = await loginWithEmailPassword(email, password);
            if (result?.user) {
                const token = result?.user.accessToken;
                if (token) {
                    const decodedToken = jwtDecode(token);
                    const userRole = decodedToken?.role;
                    if (userRole === FirebaseUserRoles.Admin || userRole === FirebaseUserRoles.SuperAdmin) {
                        localStorage.setItem(LOCAL_STORAGE_KEYS.isLoggedIn, JSON.stringify(true));
                        navigate(ROUTES.DASHBOARD);
                    }
                    else {
                        logOut();
                    }
                }
            }
            else {
                popToast({
                    type: ToastPreset.Error,
                    message: translate.pages.login.invalidFieldValues,
                });
            }
        }
        catch (error) {
            console.error('Login error: ', error);
        }
    };
    const handleForgotPassword = async () => {
        try {
            if (!email) {
                setErrors({
                    email: translate.pages.login.emailError,
                    password: '',
                });
                return;
            }
            await checkEmailExists(email);
            if (isEmailExisting) {
                forgotPassword(email);
                popToast({
                    type: ToastPreset.Success,
                    message: translate.pages.login.passwordResetMessage,
                });
            }
            else {
                popToast({
                    type: ToastPreset.Error,
                    message: translate.pages.login.emailNotExists,
                });
            }
        }
        catch (error) {
            console.error('Forgot password error: ', error);
        }
    };
    return (_jsx("div", { className: "adminLogin__container", children: _jsxs("div", { className: "adminLogin__wrapper", children: [_jsxs("div", { className: "adminLogin__leftPanel", children: [_jsx(Typography, { variant: "h4", className: "adminLogin__welcomeTitle", children: loginMessageTitle }), _jsx(Typography, { className: "adminLogin__welcomeMessage", children: loginMessage })] }), _jsxs("div", { className: "adminLogin__rightPanel", children: [_jsxs("div", { className: "adminLogin__form", children: [_jsxs("div", { className: "adminLogin__loginTextContainer", children: [_jsx(LoginIcon, { sx: { height: 30, width: 30 }, color: "primary" }), _jsx(Typography, { className: "adminLogin__loginText", children: loginTitle })] }), _jsx(AdminInput, { containerClass: "adminLogin__input", label: translate.pages.login.email, value: email, onChange: handleEmailChange, preset: InputPresets.Email, error: !!errors.email, helperText: errors.email }), _jsx(AdminInput, { containerClass: "adminLogin__input", label: translate.pages.login.password, value: password, onChange: handlePasswordChange, preset: InputPresets.Password, error: !!errors.password, helperText: errors.password }), _jsx(Typography, { className: "adminLogin__forgotPassword", onClick: handleForgotPassword, children: translate.pages.login.forgotPassword })] }), _jsx(AdminButton, { title: translate.pages.login.login, handleClick: handleLogin, buttonClass: "adminLogin__loginButton" })] })] }) }));
});
export default LoginPage;
